summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/gui/dialogs/qmessagebox.cpp4
-rw-r--r--src/gui/inputmethod/qinputcontext.cpp4
-rw-r--r--src/gui/inputmethod/qinputcontext.h2
-rw-r--r--src/gui/inputmethod/qinputcontext_p.h2
-rw-r--r--src/gui/inputmethod/qinputcontextfactory.cpp4
-rw-r--r--src/gui/inputmethod/qinputcontextfactory.h2
-rw-r--r--src/gui/inputmethod/qinputcontextplugin.cpp4
-rw-r--r--src/gui/inputmethod/qinputcontextplugin.h2
-rw-r--r--src/gui/inputmethod/qximinputcontext_p.h2
-rw-r--r--src/gui/inputmethod/qximinputcontext_x11.cpp2
-rw-r--r--src/gui/itemviews/qdatawidgetmapper.cpp2
-rw-r--r--src/gui/kernel/qmotifdnd_x11.cpp2
-rw-r--r--src/gui/painting/qprintengine_pdf.cpp2
-rw-r--r--src/plugins/inputmethods/imsw-multi/qmultiinputcontext.cpp2
-rw-r--r--src/plugins/inputmethods/imsw-multi/qmultiinputcontext.h2
-rw-r--r--src/plugins/inputmethods/imsw-multi/qmultiinputcontextplugin.cpp2
-rw-r--r--src/plugins/inputmethods/imsw-multi/qmultiinputcontextplugin.h2
-rw-r--r--src/qt_targets.pri2
-rw-r--r--src/xmlpatterns/functions/qsystempropertyfn.cpp2
19 files changed, 23 insertions, 23 deletions
diff --git a/src/gui/dialogs/qmessagebox.cpp b/src/gui/dialogs/qmessagebox.cpp
index 53bba36d93..ceaf2379cb 100644
--- a/src/gui/dialogs/qmessagebox.cpp
+++ b/src/gui/dialogs/qmessagebox.cpp
@@ -1770,10 +1770,10 @@ void QMessageBox::aboutQt(QWidget *parent, const QString &title)
"use such applications in combination with software subject to the "
"terms of the GNU GPL version 3.0 or where you are otherwise willing "
"to comply with the terms of the GNU GPL version 3.0.</p>"
- "<p>Please see <a href=\"http://qt.nokia.com/products/licensing\">qt.nokia.com/products/licensing</a> "
+ "<p>Please see <a href=\"http://qt.digia.com/products/licensing\">qt.digia.com/products/licensing</a> "
"for an overview of Qt licensing.</p>"
"<p>Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).</p>"
- "<p>Qt is a Nokia product. See <a href=\"http://qt.nokia.com/\">qt.nokia.com</a> "
+ "<p>Qt is a Digia product. See <a href=\"http://qt.digia.com/\">qt.digia.com</a> "
"for more information.</p>"
);
QMessageBox *msgBox = new QMessageBox(parent);
diff --git a/src/gui/inputmethod/qinputcontext.h b/src/gui/inputmethod/qinputcontext.h
index 931cd264b7..5a72e5739f 100644
--- a/src/gui/inputmethod/qinputcontext.h
+++ b/src/gui/inputmethod/qinputcontext.h
@@ -46,7 +46,7 @@
**
** Copyright (C) 2003-2004 immodule for Qt Project. All rights reserved.
**
-** This file is written to contribute to Nokia Corporation and/or its subsidiary(-ies) under their own
+** This file is written to contribute to Digia Plc under their own
** license. You may use this file under your Qt license. Following
** description is copied from their original file headers. Contact
** immodule-qt@freedesktop.org if any conditions of this licensing are
diff --git a/src/gui/inputmethod/qinputcontext_p.h b/src/gui/inputmethod/qinputcontext_p.h
index 6217e6c00e..14d5b4cc4b 100644
--- a/src/gui/inputmethod/qinputcontext_p.h
+++ b/src/gui/inputmethod/qinputcontext_p.h
@@ -57,7 +57,7 @@
**
** Copyright (C) 2003-2004 immodule for Qt Project. All rights reserved.
**
-** This file is written to contribute to Nokia Corporation and/or its subsidiary(-ies) under their own
+** This file is written to contribute to Digia Plc under their own
** license. You may use this file under your Qt license. Following
** description is copied from their original file headers. Contact
** immodule-qt@freedesktop.org if any conditions of this licensing are
diff --git a/src/gui/inputmethod/qinputcontextfactory.h b/src/gui/inputmethod/qinputcontextfactory.h
index 1adb9328de..47ffffbb05 100644
--- a/src/gui/inputmethod/qinputcontextfactory.h
+++ b/src/gui/inputmethod/qinputcontextfactory.h
@@ -46,7 +46,7 @@
**
** Copyright (C) 2003-2004 immodule for Qt Project. All rights reserved.
**
-** This file is written to contribute to Nokia Corporation and/or its subsidiary(-ies) under their own
+** This file is written to contribute to Digia Plc under their own
** license. You may use this file under your Qt license. Following
** description is copied from their original file headers. Contact
** immodule-qt@freedesktop.org if any conditions of this licensing are
diff --git a/src/gui/inputmethod/qinputcontextplugin.h b/src/gui/inputmethod/qinputcontextplugin.h
index 265f8ada2f..fed9a7efbd 100644
--- a/src/gui/inputmethod/qinputcontextplugin.h
+++ b/src/gui/inputmethod/qinputcontextplugin.h
@@ -46,7 +46,7 @@
**
** Copyright (C) 2003-2004 immodule for Qt Project. All rights reserved.
**
-** This file is written to contribute to Nokia Corporation and/or its subsidiary(-ies) under their own
+** This file is written to contribute to Digia Plc under their own
** license. You may use this file under your Qt license. Following
** description is copied from their original file headers. Contact
** immodule-qt@freedesktop.org if any conditions of this licensing are
diff --git a/src/gui/inputmethod/qximinputcontext_p.h b/src/gui/inputmethod/qximinputcontext_p.h
index 97a6423511..a493af6618 100644
--- a/src/gui/inputmethod/qximinputcontext_p.h
+++ b/src/gui/inputmethod/qximinputcontext_p.h
@@ -46,7 +46,7 @@
**
** Copyright (C) 2003-2004 immodule for Qt Project. All rights reserved.
**
-** This file is written to contribute to Nokia Corporation and/or its subsidiary(-ies) under their own
+** This file is written to contribute to Digia Plc under their own
** license. You may use this file under your Qt license. Following
** description is copied from their original file headers. Contact
** immodule-qt@freedesktop.org if any conditions of this licensing are
diff --git a/src/gui/inputmethod/qximinputcontext_x11.cpp b/src/gui/inputmethod/qximinputcontext_x11.cpp
index 9cee1bfc02..38a65a93b6 100644
--- a/src/gui/inputmethod/qximinputcontext_x11.cpp
+++ b/src/gui/inputmethod/qximinputcontext_x11.cpp
@@ -46,7 +46,7 @@
**
** Copyright (C) 2003-2004 immodule for Qt Project. All rights reserved.
**
-** This file is written to contribute to Nokia Corporation and/or its subsidiary(-ies) under their own
+** This file is written to contribute to Digia Plc under their own
** license. You may use this file under your Qt license. Following
** description is copied from their original file headers. Contact
** immodule-qt@freedesktop.org if any conditions of this licensing are
diff --git a/src/gui/itemviews/qdatawidgetmapper.cpp b/src/gui/itemviews/qdatawidgetmapper.cpp
index a765fe3955..241121deab 100644
--- a/src/gui/itemviews/qdatawidgetmapper.cpp
+++ b/src/gui/itemviews/qdatawidgetmapper.cpp
@@ -292,7 +292,7 @@ void QDataWidgetMapperPrivate::_q_modelDestroyed()
\snippet doc/src/snippets/code/src_gui_itemviews_qdatawidgetmapper.cpp 0
After the call to toFirst(), \c mySpinBox displays the value \c{1}, \c myLineEdit
- displays \c {Nokia Corporation and/or its subsidiary(-ies)} and \c myCountryChooser displays \c{Oslo}. The
+ displays \c {Digia Plc} and \c myCountryChooser displays \c{Oslo}. The
navigational functions toFirst(), toNext(), toPrevious(), toLast() and setCurrentIndex()
can be used to navigate in the model and update the widgets with contents from
the model.
diff --git a/src/gui/kernel/qmotifdnd_x11.cpp b/src/gui/kernel/qmotifdnd_x11.cpp
index 2a01d91f06..1e40e7cdf5 100644
--- a/src/gui/kernel/qmotifdnd_x11.cpp
+++ b/src/gui/kernel/qmotifdnd_x11.cpp
@@ -65,7 +65,7 @@ in doc/dnd.doc, where the documentation system can see it. */
/* Only requires Xlib layer - not MT safe */
/* Author: Daniel Dardailler, daniel@x.org */
/* Adapted by: Matt Koss, koss@napri.sk */
-/* Further adaptions by: Nokia Corporation and/or its subsidiary(-ies) */
+/* Further adaptions by: Digia Plc */
/***********************************************************/
#include "qplatformdefs.h"
diff --git a/src/gui/painting/qprintengine_pdf.cpp b/src/gui/painting/qprintengine_pdf.cpp
index 4cd0375d8f..ad5dc580a2 100644
--- a/src/gui/painting/qprintengine_pdf.cpp
+++ b/src/gui/painting/qprintengine_pdf.cpp
@@ -948,7 +948,7 @@ void QPdfEnginePrivate::writeInfo()
array.append((*(utf16Creator + i)) >> 8);
array.append((*(utf16Creator + i)) & 0xff);
}
- array.append(")\n/Producer (Qt " QT_VERSION_STR " (C) 2010 Nokia Corporation and/or its subsidiary(-ies))\n");
+ array.append(")\n/Producer (Qt " QT_VERSION_STR " (C) 2010 Digia Plc)\n");
write(array);
QDateTime now = QDateTime::currentDateTime().toUTC();
diff --git a/src/plugins/inputmethods/imsw-multi/qmultiinputcontext.cpp b/src/plugins/inputmethods/imsw-multi/qmultiinputcontext.cpp
index 6b0803d90e..9be0932ab6 100644
--- a/src/plugins/inputmethods/imsw-multi/qmultiinputcontext.cpp
+++ b/src/plugins/inputmethods/imsw-multi/qmultiinputcontext.cpp
@@ -46,7 +46,7 @@
**
** Copyright (C) 2004 immodule for Qt Project. All rights reserved.
**
-** This file is written to contribute to Nokia Corporation and/or its subsidiary(-ies) under their own
+** This file is written to contribute to Digia Plc under their own
** licence. You may use this file under your Qt license. Following
** description is copied from their original file headers. Contact
** immodule-qt@freedesktop.org if any conditions of this licensing are
diff --git a/src/plugins/inputmethods/imsw-multi/qmultiinputcontext.h b/src/plugins/inputmethods/imsw-multi/qmultiinputcontext.h
index a8e0458dc5..7082b464e2 100644
--- a/src/plugins/inputmethods/imsw-multi/qmultiinputcontext.h
+++ b/src/plugins/inputmethods/imsw-multi/qmultiinputcontext.h
@@ -46,7 +46,7 @@
**
** Copyright (C) 2004 immodule for Qt Project. All rights reserved.
**
-** This file is written to contribute to Nokia Corporation and/or its subsidiary(-ies) under their own
+** This file is written to contribute to Digia Plc under their own
** licence. You may use this file under your Qt license. Following
** description is copied from their original file headers. Contact
** immodule-qt@freedesktop.org if any conditions of this licensing are
diff --git a/src/plugins/inputmethods/imsw-multi/qmultiinputcontextplugin.cpp b/src/plugins/inputmethods/imsw-multi/qmultiinputcontextplugin.cpp
index 2a84f9e2a8..833b121cec 100644
--- a/src/plugins/inputmethods/imsw-multi/qmultiinputcontextplugin.cpp
+++ b/src/plugins/inputmethods/imsw-multi/qmultiinputcontextplugin.cpp
@@ -46,7 +46,7 @@
**
** Copyright (C) 2004 immodule for Qt Project. All rights reserved.
**
-** This file is written to contribute to Nokia Corporation and/or its subsidiary(-ies) under their own
+** This file is written to contribute to Digia Plc under their own
** license. You may use this file under your Qt license. Following
** description is copied from their original file headers. Contact
** immodule-qt@freedesktop.org if any conditions of this licensing are
diff --git a/src/plugins/inputmethods/imsw-multi/qmultiinputcontextplugin.h b/src/plugins/inputmethods/imsw-multi/qmultiinputcontextplugin.h
index 28896344b9..c859b1c189 100644
--- a/src/plugins/inputmethods/imsw-multi/qmultiinputcontextplugin.h
+++ b/src/plugins/inputmethods/imsw-multi/qmultiinputcontextplugin.h
@@ -46,7 +46,7 @@
**
** Copyright (C) 2004 immodule for Qt Project. All rights reserved.
**
-** This file is written to contribute to Nokia Corporation and/or its subsidiary(-ies) under their own
+** This file is written to contribute to Digia Plc under their own
** license. You may use this file under your Qt license. Following
** description is copied from their original file headers. Contact
** immodule-qt@freedesktop.org if any conditions of this licensing are
diff --git a/src/qt_targets.pri b/src/qt_targets.pri
index 54839835c3..9241f12bf5 100644
--- a/src/qt_targets.pri
+++ b/src/qt_targets.pri
@@ -1,4 +1,4 @@
-QMAKE_TARGET_COMPANY = Nokia Corporation and/or its subsidiary(-ies)
+QMAKE_TARGET_COMPANY = Digia Plc
QMAKE_TARGET_PRODUCT = Qt4
QMAKE_TARGET_DESCRIPTION = C++ application development framework.
QMAKE_TARGET_COPYRIGHT = Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
diff --git a/src/xmlpatterns/functions/qsystempropertyfn.cpp b/src/xmlpatterns/functions/qsystempropertyfn.cpp
index 976827351f..ddc64ed6be 100644
--- a/src/xmlpatterns/functions/qsystempropertyfn.cpp
+++ b/src/xmlpatterns/functions/qsystempropertyfn.cpp
@@ -80,7 +80,7 @@ QString SystemPropertyFN::retrieveProperty(const QXmlName name)
*/
return QString::number(1.20);
case StandardLocalNames::vendor:
- return QLatin1String("Nokia Corporation and/or its subsidiary(-ies), a Nokia Company");
+ return QLatin1String("Digia Plc");
case StandardLocalNames::vendor_url:
return QLatin1String("http://qt.nokia.com/");
case StandardLocalNames::product_name:
diff --git a/src/gui/inputmethod/qinputcontext.cpp b/src/gui/inputmethod/qinputcontext.cpp
index 4ede287729..3138631f6d 100644
--- a/src/gui/inputmethod/qinputcontext.cpp
+++ b/src/gui/inputmethod/qinputcontext.cpp
@@ -46,7 +46,7 @@
**
** Copyright (C) 2003-2004 immodule for Qt Project. All rights reserved.
**
** This file is written to contribute to Nokia Corporation and/or its subsidiary(-ies) under their own
** license. You may use this file under your Qt license. Following
** description is copied from their original file headers. Contact
** immodule-qt@freedesktop.org if any conditions of this licensing are
@@ -130,7 +130,7 @@ QT_BEGIN_NAMESPACE
\legalese
Copyright (C) 2003-2004 immodule for Qt Project. All rights reserved.
- This file is written to contribute to Nokia Corporation and/or its subsidiary(-ies) under their own
+ This file is written to contribute to Digia Plc under their own
license. You may use this file under your Qt license. Following
description is copied from their original file headers. Contact
immodule-qt@freedesktop.org if any conditions of this licensing are
@@ -46,7 +46,7 @@
** Copyright (C) 2003-2004 immodule for Qt Project. All rights reserved.
**
-** This file is written to contribute to Nokia Corporation and/or its subsidiary(-ies) under their own
+** This file is written to contribute to Digia Plc under their own
** license. You may use this file under your Qt license. Following
** description is copied from their original file headers. Contact
diff --git a/src/gui/inputmethod/qinputcontextfactory.cpp b/src/gui/inputmethod/qinputcontextfactory.cpp
index 60be6fc26f..80ae51c0b8 100644
--- a/src/gui/inputmethod/qinputcontextfactory.cpp
+++ b/src/gui/inputmethod/qinputcontextfactory.cpp
@@ -46,7 +46,7 @@
**
** Copyright (C) 2003-2004 immodule for Qt Project. All rights reserved.
**
** This file is written to contribute to Nokia Corporation and/or its subsidiary(-ies) under their own
** license. You may use this file under your Qt license. Following
** description is copied from their original file headers. Contact
** immodule-qt@freedesktop.org if any conditions of this licensing are
@@ -114,7 +114,7 @@ Q_GLOBAL_STATIC_WITH_ARGS(QFactoryLoader, loader,
\legalese
Copyright (C) 2003-2004 immodule for Qt Project. All rights reserved.
- This file is written to contribute to Nokia Corporation and/or its subsidiary(-ies) under their own
+ This file is written to contribute to Digia Plc under their own
license. You may use this file under your Qt license. Following
description is copied from their original file headers. Contact
immodule-qt@freedesktop.org if any conditions of this licensing are
@@ -46,7 +46,7 @@
** Copyright (C) 2003-2004 immodule for Qt Project. All rights reserved.
**
-** This file is written to contribute to Nokia Corporation and/or its subsidiary(-ies) under their own
+** This file is written to contribute to Digia Plc under their own
** license. You may use this file under your Qt license. Following
** description is copied from their original file headers. Contact
diff --git a/src/gui/inputmethod/qinputcontextplugin.cpp b/src/gui/inputmethod/qinputcontextplugin.cpp
index b2517a5d5a..306c726004 100644
--- a/src/gui/inputmethod/qinputcontextplugin.cpp
+++ b/src/gui/inputmethod/qinputcontextplugin.cpp
@@ -46,7 +46,7 @@
**
** Copyright (C) 2003-2004 immodule for Qt Project. All rights reserved.
**
** This file is written to contribute to Nokia Corporation and/or its subsidiary(-ies) under their own
** license. You may use this file under your Qt license. Following
** description is copied from their original file headers. Contact
** immodule-qt@freedesktop.org if any conditions of this licensing are
@@ -80,7 +80,7 @@ QT_BEGIN_NAMESPACE
\legalese
Copyright (C) 2003-2004 immodule for Qt Project. All rights reserved.
- This file is written to contribute to Nokia Corporation and/or its subsidiary(-ies) under their own
+ This file is written to contribute to Digia Plc under their own
license. You may use this file under your Qt license. Following
description is copied from their original file headers. Contact
immodule-qt@freedesktop.org if any conditions of this licensing are
@@ -46,7 +46,7 @@
** Copyright (C) 2003-2004 immodule for Qt Project. All rights reserved.
**
-** This file is written to contribute to Nokia Corporation and/or its subsidiary(-ies) under their own
+** This file is written to contribute to Digia Plc under their own
** license. You may use this file under your Qt license. Following
** description is copied from their original file headers. Contact